@@ -38,8 +38,6 @@
 #include "hd-render-manager.h"
 #include "hd-clutter-cache.h"
 #include "hd-theme.h"
-#include "hd-dbus.h"
-#include "hd-title-bar.h"
 
 #include "hd-launcher-app.h"
 
@@ -87,7 +85,7 @@
 #define INDICATION_WIDTH 50
 #define HD_EDGE_INDICATION_COLOR "SelectionColor"
 
-#define MAX_VIEWS 8
+#define MAX_VIEWS 4
 
 #define FN_KEY GDK_ISO_Level3_Shift
 #define FN_MODIFIER Mod5Mask
@@ -99,8 +97,6 @@
 #define DRAG_DEBUG(...)
 //#define DRAG_DEBUG g_debug
 
-gboolean in_alt_tab;
-
 enum
 {
   PROP_COMP_MGR = 1,
@@ -175,8 +171,7 @@ struct _HdHomePrivate
     FN_STATE_NONE,      // interpret the KeyPress as it is
     FN_STATE_NEXT,      // the next key is Fn-modified
     FN_STATE_LOCKED,    // until turned off all key press are Fn-modified
-  } fn_state, shift_state;
-  time_t last_fn_time;
+  } fn_state;
 
   enum
   {
@@ -189,7 +184,6 @@ struct _HdHomePrivate
   /* For hd_home_desktop_key_release():
    * Don't change @fn_state if it was wasn't pressed alone. */
   gboolean ignore_next_fn_release;
-  gboolean ignore_next_shift_release;
   /* These are all reset when the HDRM state is changed. */
 
   /* addressbook and Call UI D-Bus interfaces (name, path, method) */
@@ -221,8 +215,6 @@ static void hd_home_constructed (GObject *object);
 
 static void hd_home_show_edit_button (HdHome *home);
 
-static void hd_home_reset_fn_state (HdHome *home);
-
 static void do_applet_release (HdHome             *home,
                                ClutterActor       *applet,
                                ClutterButtonEvent *event);
@@ -312,7 +304,6 @@ hd_home_live_bg_emit_button1_event (
                              &xev.x, &xev.y,
                              &mywindow);
     }
-  xev.x += priv->cumulative_x;
   XSendEvent(wm->xdpy, xev.window, True, 0, (XEvent *)&xev);
 }
 
@@ -696,125 +687,11 @@ hd_home_desktop_key_press (XKeyEvent *xev, void *userdata)
     }
 
   /* We don't care if Ctrl is pressed. */
-  if (xev->state & ControlMask){
-	 hd_home_reset_fn_state(home);
-	 return;
-  }
+  if (xev->state & ControlMask)
+    return;
 
 /*  g_debug ("%s, display: %p, keymap: %p", __FUNCTION__, display, keymap); */
 
-  if (hd_render_manager_get_state()==HDRM_STATE_LAUNCHER) {
-          int d;
-          d=0;
-          switch(xev->keycode) {
-                  case 24:
-                  case 25:
-                  case 26:
-                  case 27:
-                  case 28:
-                          d=24;
-                          break;
-                  case 38:
-                  case 39:
-                  case 40:
-                  case 41:
-                  case 42:
-                          d=33;
-                          break;
-                  case 52:
-                  case 53:
-                  case 54:
-                  case 55:
-                  case 56:
-                          d=42;
-                          break;
-                  case 22: /* Backspace sends -1, which means up one level */
-                          d=23;
-                          break;
-          }
-          if (d && conf_enable_launcher_navigator_accel) {
-                hd_launcher_activate(xev->keycode-d);
-          } else if(conf_enable_dbus_launcher_navigator) {
-                char s[16];
-                gdk_keymap_translate_keyboard_state (keymap,
-                                       xev->keycode,
-                                       xev->state,
-                                       0,
-                                       &keyval,
-                                       NULL, NULL, NULL);
-                sprintf(s, "%i", keyval+1024);
-                hd_dbus_send_event(s);
-          }
-  }
-  if (hd_render_manager_get_state()==HDRM_STATE_TASK_NAV) {
-          int d,y;
-          d=0;
-          switch(xev->keycode) {
-                  case 24:
-                  case 25:
-                  case 26:
-                  case 27:
-                  case 28:
-                          d=24;
-                          y=0;
-                          break;
-                  case 38:
-                  case 39:
-                  case 40:
-                  case 41:
-                  case 42:
-                          d=38;
-                          y=1;
-                          break;
-                  case 52:
-                  case 53:
-                  case 54:
-                  case 55:
-                  case 56:
-                          d=52;
-                          y=2;
-                          break;
-          }
-          if (d && conf_enable_launcher_navigator_accel) {
-		 time (&now);
-                 if ((xev->state & (FN_MODIFIER|ShiftMask))||(
-					 (difftime (now, priv->last_fn_time) < 4)
-					 &&(priv->fn_state||priv->shift_state)
-					 )) {
-                         hd_task_navigator_activate(xev->keycode-d,y,1);
-                         hd_home_reset_fn_state(home);
-                 } else hd_task_navigator_activate(xev->keycode-d,y,0);
-          } else if(conf_enable_dbus_launcher_navigator) {
-                char s[16];
-                gdk_keymap_translate_keyboard_state (keymap,
-                                       xev->keycode,
-                                       xev->state,
-                                       0,
-                                       &keyval,
-                                       NULL, NULL, NULL);
-                sprintf(s, "%i", keyval+2048);
-                hd_dbus_send_event(s);
-          }
-  }
-  if (hd_render_manager_get_state()==HDRM_STATE_HOME) {
-	  gdk_keymap_translate_keyboard_state (keymap,
-                                       xev->keycode,
-                                       xev->state,
-                                       0,
-                                       &keyval,
-                                       NULL, NULL, NULL);
-	  g_warning("kv=%i   %i %i", keyval, GDK_Left, GDK_Right);
-	  if (keyval==GDK_Left) {
-		  hd_home_view_container_scroll_to_previous (HD_HOME_VIEW_CONTAINER (priv->view_container), 20000);
-		  return ;
-	  }
-	  if (keyval==GDK_Right) {
-		  hd_home_view_container_scroll_to_next (HD_HOME_VIEW_CONTAINER (priv->view_container), -20000);
-		  return ;
-	  }
-	  
-  if(conf_enable_home_contacts_phone) {
-
   /* First check how long has it been since last key press. If more than n sec,
    * reset.
    */
@@ -829,7 +706,7 @@ hd_home_desktop_key_press (XKeyEvent *xev, void *userdata)
    * already sent some to Contacts or CallUI. */
   if (!STATE_ALLOW_CALL_FROM_HOME (hd_render_manager_get_state ()) &&
       (priv->key_sent == KEY_SENT_NONE))
-    goto handle_fn_shift;
+    return;
 
   if (priv->key_sent == KEY_SENT_CALLUI)
     {
@@ -903,20 +780,7 @@ hd_home_desktop_key_press (XKeyEvent *xev, void *userdata)
                 G_TYPE_STRING, buffer, G_TYPE_INVALID);
         }
     }
- } else if(conf_enable_dbus_launcher_navigator) {
-	char s[16];
-	gdk_keymap_translate_keyboard_state (keymap,
-		       xev->keycode,
-		       xev->state,
-		       0,
-		       &keyval,
-		       NULL, NULL, NULL);
-		sprintf(s, "%i", keyval+4096); 
-		hd_dbus_send_event(s);
- }
-  }
 
-handle_fn_shift:
  if (xev->state & FN_MODIFIER)
    {
      priv->fn_state = FN_STATE_NONE;
@@ -927,23 +791,6 @@ handle_fn_shift:
      priv->fn_state = FN_STATE_NONE;
      g_debug ("%s, FN state: %d", __FUNCTION__, priv->fn_state);
    }
- if (xev->state & ShiftMask)
-   {
-     priv->shift_state = FN_STATE_NONE;
-     priv->ignore_next_shift_release = TRUE;
-   }
- else if (priv->shift_state == FN_STATE_NEXT)
-   {
-     priv->shift_state = FN_STATE_NONE;
-     g_debug ("%s, SHIFT state: %d", __FUNCTION__, priv->shift_state);
-   }
-  if(XkbKeycodeToKeysym(clutter_x11_get_default_display(), xev->keycode, 0, 0) == FN_KEY) {
-	  priv->ignore_next_fn_release = FALSE;
-  }
-  if(XkbKeycodeToKeysym(clutter_x11_get_default_display(), xev->keycode, 0, 0) == GDK_Shift_L) {
-	  priv->ignore_next_shift_release = FALSE;
-  }
-	
 }
 
 static void
@@ -952,57 +799,26 @@ hd_home_desktop_key_release (XKeyEvent *xev, void *userdata)
   HdHome *home = userdata;
   HdHomePrivate *priv = home->priv;
 
+  /* Ignore keys if they are not Fn. */
+  if (xev->state & ControlMask
+      || XkbKeycodeToKeysym(clutter_x11_get_default_display(),
+                            xev->keycode, 0, 0) != FN_KEY)
+    return;
 
   /* Ignore keys if not at home or launching an app that wants them. */
   if (!STATE_ALLOW_CALL_FROM_HOME (hd_render_manager_get_state ()) &&
-      (priv->key_sent == KEY_SENT_NONE) && (hd_render_manager_get_state()!=HDRM_STATE_TASK_NAV))
+      (priv->key_sent == KEY_SENT_NONE))
       return;
 
-  if((XkbKeycodeToKeysym(clutter_x11_get_default_display(), xev->keycode, 0, 0) == GDK_Control_L) &&
-  	(hd_render_manager_get_state () == HDRM_STATE_TASK_NAV ) &&
-	(conf_ctrl_backspace_in_tasknav==5) && in_alt_tab) {
-	  in_alt_tab=FALSE;
-	  hd_task_navigator_activate(0, 0, 0);
-  }
-
-  if(xev->state & ControlMask) {
-	  priv->fn_state = FN_STATE_NONE;
-	  priv->shift_state = FN_STATE_NONE;
-	  priv->ignore_next_fn_release = TRUE;
-	  priv->ignore_next_shift_release = TRUE;
-	  return ;
-  }
-
-  if(XkbKeycodeToKeysym(clutter_x11_get_default_display(), xev->keycode, 0, 0) == FN_KEY) {
-	  if (priv->ignore_next_fn_release)
-	    priv->ignore_next_fn_release = FALSE;
-	  else if (priv->fn_state == FN_STATE_NONE)
-	    priv->fn_state = FN_STATE_NEXT;
-	  else if (priv->fn_state == FN_STATE_NEXT)
-	    priv->fn_state = FN_STATE_LOCKED;
-	  else
-	    priv->fn_state = FN_STATE_NONE;
-	  if(priv->fn_state && (hd_render_manager_get_state()==HDRM_STATE_TASK_NAV)) {
-		  hd_home_show_edit_button(home);
-		  time(&priv->last_fn_time);
-	  }
-//	  g_warning ("%s. FN state: %d", __FUNCTION__, priv->fn_state);
-  }
-  if(XkbKeycodeToKeysym(clutter_x11_get_default_display(), xev->keycode, 0, 0) == GDK_Shift_L) {
-	  if (priv->ignore_next_shift_release)
-	    priv->ignore_next_shift_release = FALSE;
-	  else if (priv->shift_state == FN_STATE_NONE)
-	    priv->shift_state = FN_STATE_NEXT;
-	  else if (priv->shift_state == FN_STATE_NEXT)
-	    priv->shift_state = FN_STATE_LOCKED;
-	  else
-	    priv->shift_state = FN_STATE_NONE;
-	  if(priv->shift_state && (hd_render_manager_get_state()==HDRM_STATE_TASK_NAV)) {
-		  hd_home_show_edit_button(home);
-		  time(&priv->last_fn_time);
-	  }
-//	  g_warning ("%s. SHIFT state: %d", __FUNCTION__, priv->shift_state);
-	}
+  if (priv->ignore_next_fn_release)
+    priv->ignore_next_fn_release = FALSE;
+  else if (priv->fn_state == FN_STATE_NONE)
+    priv->fn_state = FN_STATE_NEXT;
+  else if (priv->fn_state == FN_STATE_NEXT)
+    priv->fn_state = FN_STATE_LOCKED;
+  else
+    priv->fn_state = FN_STATE_NONE;
+  g_debug ("%s. FN state: %d", __FUNCTION__, priv->fn_state);
 }
 
 static void
@@ -1010,8 +826,6 @@ hd_home_reset_fn_state (HdHome *home)
 {
   home->priv->fn_state = FN_STATE_NONE;
   home->priv->ignore_next_fn_release = FALSE;
-  home->priv->shift_state = FN_STATE_NONE;
-  home->priv->ignore_next_shift_release = FALSE;
 }
 
 /*
@@ -2247,8 +2061,6 @@ hd_home_edit_button_timeout (gpointer data)
 
   hd_home_hide_edit_button (home);
 
-  hd_home_reset_fn_state(home);
-
   return FALSE;
 }
 
@@ -2614,7 +2426,3 @@ hd_home_unregister_applet (HdHome       *home,
   if (HD_IS_HOME_VIEW (view))
     hd_home_view_unregister_applet (view, applet);
 }
-
-HdHomeViewContainer *hd_home_get_view_container(HdHome *home) {
-	return HD_HOME_VIEW_CONTAINER (home->priv->view_container);
-}
