@@ -268,7 +268,8 @@ gboolean hd_render_manager_actor_is_visible(ClutterActor *actor);
 
 void hd_render_manager_set_visibilities(void);
 
-HdHome *hd_render_manager_get_home (void);
+void hd_render_manager_update_blur_state(void);
+void hd_render_manager_pause_blur_animation(void);
 
 G_END_DECLS
 
