@@ -434,11 +434,6 @@ void hd_launcher_grid_layout (HdLauncherGrid *grid)
 
   cur_height = HD_LAUNCHER_PAGE_YMARGIN;
 
-  /* This actually does the scrolling, instead of us using
-   * cogl_translate like we did previously, which kills software
-   * selection mode */
-  cur_height -= tidy_adjustment_get_value(priv->v_adjustment);
-
   l = priv->tiles;
   while (l) {
     /* Allocate all icons on this row */
@@ -861,15 +856,3 @@ _hd_launcher_grid_blocker_release_cb (ClutterActor *actor,
 {
   return TRUE;
 }
-
-void hd_launcher_grid_activate(ClutterActor *actor, int p)
-{
-	HdLauncherGridPrivate *priv = HD_LAUNCHER_GRID_GET_PRIVATE (actor);
-	GList *l;
-	l=priv->tiles;
-	while((p>0) && l) {
-		l=l->next;
-		p--;
-	}
-	if(l && !p) hd_launcher_tile_activate(l->data);
-}
