@@ -153,6 +153,23 @@ x_window_property_changed (XPropertyEvent *event, HdNote *self)
     }
 }
 
+static void
+hd_note_show (MBWindowManagerClient *client)
+{
+  MBWMCompMgrClutterClient *cclient = MB_WM_COMP_MGR_CLUTTER_CLIENT (client->cm_client);
+  MBWindowManagerClientClass* parent_klass =
+      MB_WM_CLIENT_CLASS (MB_WM_OBJECT_GET_PARENT_CLASS(MB_WM_OBJECT(client)));
+
+  parent_klass->show (client);
+
+  /* Indicate to the libmatchbox code that the actor visibility and positioning
+   * logic will be overridden. */
+  if (HD_IS_INCOMING_EVENT_PREVIEW_NOTE(client))
+    mb_wm_comp_mgr_clutter_client_set_flags (cclient,
+                                             MBWMCompMgrClutterClientDontShow|
+                                             MBWMCompMgrClutterClientDontPosition);
+}
+
 static void
 hd_note_class_init (MBWMObjectClass *klass)
 {
@@ -167,6 +184,7 @@ hd_note_class_init (MBWMObjectClass *klass)
   client->geometry     = hd_note_request_geometry;
   client->stack        = hd_note_stack;
   client->stacking_layer = hd_note_stacking_layer;
+  client->show         = hd_note_show;
 
 #if MBWM_WANT_DEBUG
   klass->klass_name = "HdNote";
@@ -272,24 +290,6 @@ hd_note_init (MBWMObject *this, va_list vap)
       geom.width  = w + client->window->geometry.width  + e;
       geom.height = n + client->window->geometry.height + s;
 
-      if (hd_render_manager_get_state() == HDRM_STATE_NON_COMPOSITED)
-        {
-          /* This is to fix bug 134348 - preview notes momentarily
-           * visible over non-composited mode.
-           *
-           * Stacking these notes lower has no effect on the flicker.
-           * We assume this is because the stacking occurs after the window
-           * is mapped. In composited mode this is no problem, but in
-           * non-composited mode it means flicker.
-           *
-           * Since the stacking has no effect, I have left it as before,
-           * and instead moved the preview notes off of the screen. It
-           * may be that stacking can be fixed so there is no flicker,
-           * however while in code freeze we want the solution that is
-           * least likely to cause regression. */
-          geom.y = -(geom.height+1);
-        }
-
       hd_note_request_geometry (client, &geom, MBWMClientReqGeomForced);
     }
   else /* Banner, Info, Confirmation */
@@ -352,6 +352,7 @@ hd_note_request_geometry (MBWindowManagerClient *client,
   const MBGeometry * geom;
   Bool               change_pos;
   Bool               change_size;
+  MBWindowManager *wm = client->wmref;
 
   /* create a copy here, as we don't want to change the value that
    * was passed in... */
@@ -366,13 +367,13 @@ hd_note_request_geometry (MBWindowManagerClient *client,
   geom = (flags & MBWMClientReqGeomIsViaConfigureReq) ?
     &client->window->geometry : &client->frame_geometry;
 
-  /* Make absolutely sure that the note is placed offscreen when in
-   * non-composited mode, as stacking it low still appears to cause
-   * some flickering. See the comments in hd_note_init. */
-  if ((HD_NOTE (client)->note_type == HdNoteTypeIncomingEventPreview ||
-       HD_NOTE (client)->note_type == HdNoteTypeIncomingEvent) &&
-      hd_render_manager_get_state() == HDRM_STATE_NON_COMPOSITED)
-    new_geometry.y = -(1 + new_geometry.height);
+  if (HD_IS_CONFIRMATION_NOTE (client))
+    {
+      int diff;
+      /* make sure it's bottom-aligned */
+      diff = (new_geometry.y + new_geometry.height) - wm->xdpy_height;
+      new_geometry.y -= diff;
+    }
 
   /*
    * We only allow resizing and moving in the y axis, since notes are
@@ -384,7 +385,6 @@ hd_note_request_geometry (MBWindowManagerClient *client,
   if (change_size || (flags & MBWMClientReqGeomForced))
     {
       int north = 0, south = 0, west = 0, east = 0;
-      MBWindowManager *wm = client->wmref;
 
       if (client->decor)
 	mb_wm_theme_get_decor_dimensions (wm->theme, client,
@@ -431,6 +431,20 @@ hd_note_request_geometry (MBWindowManagerClient *client,
 	  client->frame_geometry.width  = new_geometry.width;
 	  client->frame_geometry.height = new_geometry.height;
 
+          if (HD_IS_CONFIRMATION_NOTE (client)
+              && !(client->window->ewmh_state & MBWMClientWindowEWMHStateFullscreen))
+            {
+              int diff;
+
+              diff  = 0*client->frame_geometry.y + client->frame_geometry.height;
+              diff -= wm->xdpy_height - HD_COMP_MGR_TOP_MARGIN;
+              if (diff > 0)
+                {
+                  client->frame_geometry.height -= diff;
+                  client->frame_geometry.y      += diff;
+                }
+            }
+
 	  client->window->geometry.x
 	    = client->frame_geometry.x + west;
 	  client->window->geometry.y
@@ -473,11 +487,30 @@ MBWMStackLayerType
 hd_note_stacking_layer(MBWindowManagerClient *client)
 {
   MBWindowManagerClientClass *parent;
+  Window dialog;
+  MBWindowManager *wm;
 
   if (HD_NOTE (client)->note_type == HdNoteTypeIncomingEvent)
     return MBWMStackLayerUnknown;
 
-  parent = MB_WM_CLIENT_CLASS (MB_WM_OBJECT_GET_PARENT_CLASS(MB_WM_OBJECT(client)));
+  /* if there is an application menu and 'application not responding' note,
+   * stack the note above the menu */
+  wm = client->wmref;
+  dialog = hd_wm_get_hung_client_dialog_xid (wm);
+  if (dialog && dialog == client->window->xwindow)
+    {
+      MBWindowManagerClient *c;
+
+      for (c = wm->stack_top; c && c != wm->desktop; c = c->stacked_below)
+        {
+          if (mb_wm_client_is_map_confirmed (c) &&
+              MB_WM_CLIENT_CLIENT_TYPE (c) == HdWmClientTypeAppMenu)
+            return c->stacking_layer;
+        }
+    }
+
+  parent = MB_WM_CLIENT_CLASS (MB_WM_OBJECT_GET_PARENT_CLASS (
+                                   MB_WM_OBJECT (client)));
   return parent->stacking_layer (client);
 }
 
@@ -508,7 +541,8 @@ hd_note_clicked (HdNote *self, void *unused, void *actor)
   cmgrc = g_object_get_data(actor, "HD-MBWMCompMgrClutterClient");
   if (!cmgrc || cmgrc->wm_client != c || !c->wmref)
     return;
-  if (!hd_wm_has_modal_blockers (c->wmref))
+
+  if (hd_wm_close_modal_blockers (c->wmref))
     hd_util_click (MB_WM_CLIENT (self));
 }
 
@@ -543,10 +577,11 @@ const char *hd_note_get_##field (HdNote *self)                                \
   mbwm_return_val_if_fail (self->note_type == HdNoteTypeIncomingEvent, NULL); \
   if (!self->properties[prop])                                                \
     {                                                                         \
-      mb_wm_util_trap_x_errors ();                                            \
+      mb_wm_util_async_trap_x_errors (                                        \
+          MB_WM_CLIENT(self)->wmref->xdpy);                                      \
       self->properties[prop] = get_x_window_string_property (self,            \
                   IEProperties[prop]);                                        \
-      mb_wm_util_untrap_x_errors ();                                          \
+      mb_wm_util_async_untrap_x_errors ();                                    \
     }                                                                         \
   return self->properties[prop];                                              \
 }
